@@ -2,7 +2,7 @@ from pathlib import Path
 
 import click
 
-from icepack import IcepackReader, IcepackWriter
+from icepack import IcepackReader, create_archive, extract_archive
 from icepack.helper import Age, File, SSH
 from icepack.meta import NAME, VERSION, SECRET_KEY, PUBLIC_KEY
 from icepack.model import Compression
@@ -44,42 +44,45 @@ def init(ctx):
 @icepack.command()
 @click.argument('src', type=click.Path(exists=True))
 @click.argument('dst', type=click.Path())
+@click.option('--comment', help='Archive comment.')
 @click.option(
     '--compression', '-c',
-    help='Compression type for all entries.',
+    help='Compression for all files.',
     type=click.Choice([c.value for c in Compression]),
     default=Compression.BZ2)
+@click.option(
+    '--mode',
+    help='Store file/directory modes.',
+    is_flag=True)
+@click.option(
+    '--mtime',
+    help='Store file/directory modification times.',
+    is_flag=True)
 @click.option(
     '--recipient', '-r',
-    help='Allow another recipient to extract the archive.',
+    help='Allow another public key/alias to extract.',
     multiple=True)
 @click.pass_context
-def create(ctx, src, dst, compression, recipient):
+def create(ctx, src, dst, comment, compression, mode, mtime, recipient):
     """Store files in an archive.
 
     SRC must be a file or directory, DST must be the archive file.
     """
-    src_path = Path(src).resolve()
-    dst_path = Path(dst).resolve()
-    if src_path.is_file():
-        sources = [src_path]
-    elif src_path.is_dir():
-        sources = list(File.children(src_path))
-        sources.sort(key=_sort_key)
-    else:
-        raise click.ClickException(f'Invalid source: {src_path}')
-    base = src_path.parent
+    src_path = Path(src)
+    dst_path = Path(dst)
     key_path = ctx.obj['config_path']
     _check_keys(key_path)
-    signers = SSH.get_signers(key_path)
-    aliases = {alias: key for key, alias in signers if alias is not None}
-    recipients = [aliases[r] if r in aliases else r for r in recipient]
     try:
-        with IcepackWriter(dst_path, key_path, compression=compression, extra_recipients=recipients) as archive:  # noqa
-            for source in sources:
-                click.echo(source.relative_to(base))
-                archive.add_entry(source, base)
-            archive.add_metadata()
+        create_archive(
+            src_path,
+            dst_path,
+            key_path,
+            comment=comment,
+            compression=compression,
+            mode=mode,
+            mtime=mtime,
+            recipients=recipient,
+            log=click.echo)
     except Exception as e:
         raise click.ClickException(f'Archive creation failed: {e}')
 
@@ -87,23 +90,32 @@ def create(ctx, src, dst, compression, recipient):
 @icepack.command()
 @click.argument('src', type=click.Path(exists=True, dir_okay=False))
 @click.argument('dst', type=click.Path(exists=True, file_okay=False))
+@click.option(
+    '--mode',
+    help='Restore file/directory modes.',
+    is_flag=True)
+@click.option(
+    '--mtime',
+    help='Restore file/directory modification times.',
+    is_flag=True)
 @click.pass_context
-def extract(ctx, src, dst):
+def extract(ctx, src, dst, mode, mtime):
     """Extract files from an archive.
 
     SRC must be the archive file, DST must be a directory.
     """
-    src_path = Path(src).resolve()
-    dst_path = Path(dst).resolve()
-    if not dst_path.is_dir():
-        raise click.ClickException(f'Invalid destination: {dst_path}')
+    src_path = Path(src)
+    dst_path = Path(dst)
     key_path = ctx.obj['config_path']
     _check_keys(key_path)
     try:
-        with IcepackReader(src_path, key_path) as archive:
-            for entry in archive.metadata.entries:
-                click.echo(entry.name)
-                archive.extract_entry(entry, dst_path)
+        extract_archive(
+            src_path,
+            dst_path,
+            key_path,
+            mode=mode,
+            mtime=mtime,
+            log=click.echo)
     except Exception as e:
         raise click.ClickException(f'Archive extraction failed: {e}')
 
@@ -118,6 +130,8 @@ def list_archive(ctx, src):
     _check_keys(key_path)
     try:
         with IcepackReader(src_path, key_path) as archive:
+            if archive.metadata.comment:
+                click.echo(f'Comment: {archive.metadata.comment}')
             for entry in archive.metadata.entries:
                 click.echo(entry.name)
     except Exception as e:
@@ -224,13 +238,5 @@ def _check_keys(key_path):
         raise click.ClickException(msg)
 
 
-def _sort_key(path):
-    """Sort key for Paths."""
-    key = str(path).casefold()
-    if path.is_dir:
-        key += '/'
-    return key
-
-
 if __name__ == '__main__':
     icepack()
